@@ -131,8 +131,9 @@ class Sonnen:
             async with aiohttp.ClientSession(
                 headers=self.header, timeout=self.TIMEOUT
             ) as session:
-                response = await session.get(url)
-                return await response.json()
+                resp = await session.get(url)
+                data = resp.json()
+                return await data
         except aiohttp.ClientError as error:
             self._log_error(f'Battery: {self.ip_address} is offline!')
         except asyncio.TimeoutError as error:
